@@ -3,10 +3,11 @@ V1 Admin Categories
 """
 
 from ....internals.list_resources import ListResources
+from ....internals.list_all_resources import ListAllResources
 from ....internals.post_resources import PostResources
 
 
-class Categories(ListResources, PostResources):
+class Categories(ListResources, ListAllResources, PostResources):
     """Class for Categories APIs."""
 
     CATEGORIES = '/categories'
