@@ -3,10 +3,11 @@ V1 Admin Projects
 """
 
 from ....internals.list_resources import ListResources
+from ....internals.list_all_resources import ListAllResources
 from ....internals.post_resources import PostResources
 
 
-class Projects(ListResources, PostResources):
+class Projects(ListResources, ListAllResources, PostResources):
     """Class for Projects APIs."""
 
     PROJECTS = '/projects'
